import{wt as e}from"./mui-B6lh3XSP.js";import{t}from"./Skeleton-C-luRk4q.js";import{Dt as n,wt as r}from"./index-KVuxnkWj.js";var i=e(),a=({columns:e,startAction:a,endAction:o,ref:s})=>[...[,,,]].map((c,l)=>(0,i.jsx)(r,{ref:l===0?s:null,children:[...Array(e)].map((r,s)=>{let c=a&&s===0||o&&s===e-1;return(0,i.jsx)(n,{padding:c?`none`:`normal`,children:!c&&(0,i.jsx)(t,{})},-s)})},-l));export{a as t};