import{i as e}from"./chunk-aKtaBQYM.js";import{H as t,K as n,U as r,Vt as i,W as a,dt as o,ft as s,nt as c,tt as l,ut as u,wt as d}from"./mui-B6lh3XSP.js";import{m as f}from"./List-D4mHuGFJ.js";import{Bt as p,Gt as m,Ht as h,Kt as g,Nt as _,Pt as v,mn as y}from"./index-KVuxnkWj.js";var b=e(i(),1);function x(e){return o(`MuiFormHelperText`,e)}var S=u(`MuiFormHelperText`,[`root`,`error`,`disabled`,`sizeSmall`,`sizeMedium`,`contained`,`focused`,`filled`,`required`]),C=d(),w,T=e=>{let{classes:n,contained:r,size:i,disabled:a,error:o,filled:s,focused:c,required:u}=e;return l({root:[`root`,a&&`disabled`,o&&`error`,i&&`size${t(i)}`,r&&`contained`,c&&`focused`,s&&`filled`,u&&`required`]},x,n)},E=n(`p`,{name:`MuiFormHelperText`,slot:`Root`,overridesResolver:(e,n)=>{let{ownerState:r}=e;return[n.root,r.size&&n[`size${t(r.size)}`],r.contained&&n.contained,r.filled&&n.filled]}})(a(({theme:e})=>({color:(e.vars||e).palette.text.secondary,...e.typography.caption,textAlign:`left`,marginTop:3,marginRight:0,marginBottom:0,marginLeft:0,[`&.${S.disabled}`]:{color:(e.vars||e).palette.text.disabled},[`&.${S.error}`]:{color:(e.vars||e).palette.error.main},variants:[{props:{size:`small`},style:{marginTop:4}},{props:({ownerState:e})=>e.contained,style:{marginLeft:14,marginRight:14}}]}))),ee=b.forwardRef(function(e,t){let n=r({props:e,name:`MuiFormHelperText`}),{children:i,className:a,component:o=`p`,disabled:c,error:l,filled:u,focused:d,margin:f,required:p,variant:m,...h}=n,[g]=y({props:n,states:[`variant`,`size`,`disabled`,`error`,`filled`,`focused`,`required`]}),_={...n,component:o,contained:g.variant===`filled`||g.variant===`outlined`,variant:g.variant,size:g.size,disabled:g.disabled,error:g.error,filled:g.filled,focused:g.focused,required:g.required};return delete _.ownerState,(0,C.jsx)(E,{as:o,className:s(T(_).root,a),ref:t,...h,ownerState:_,children:i===` `?w||=(0,C.jsx)(`span`,{className:`notranslate`,"aria-hidden":!0,children:`​`}):i})});function D(e){return o(`MuiTextField`,e)}u(`MuiTextField`,[`root`]);var O={standard:h,filled:g,outlined:v},k=e=>{let{classes:t}=e;return l({root:[`root`]},D,t)},te=n(m,{name:`MuiTextField`,slot:`Root`})({}),A=b.forwardRef(function(e,t){let n=r({props:e,name:`MuiTextField`}),{autoComplete:i,autoFocus:a=!1,children:o,className:l,color:u=`primary`,defaultValue:d,disabled:m=!1,error:h=!1,fullWidth:g=!1,helperText:v,id:y,inputRef:b,label:x,maxRows:S,minRows:w,multiline:T=!1,name:E,onBlur:D,onChange:A,onFocus:j,placeholder:M,required:N=!1,rows:P,select:F=!1,slots:I={},slotProps:L={},type:ne,value:R,variant:z=`outlined`,...re}=n,B={...n,autoFocus:a,color:u,disabled:m,error:h,fullWidth:g,multiline:T,required:N,select:F,variant:z},V=k(B),H=c(y),U=v&&H?`${H}-helper-text`:void 0,W=x&&H?`${H}-label`:void 0,G=O[z],K={slots:I,slotProps:L},[q,J]=f(`select`,{elementType:_,externalForwardedProps:K,ownerState:B}),Y=F&&J.native,X={},Z=K.slotProps.inputLabel;z===`outlined`&&(Z&&Z.shrink!==void 0&&(X.notched=Z.shrink),X.label=x),F&&(Y||(X.id=void 0),X[`aria-describedby`]=void 0);let[ie,ae]=f(`root`,{elementType:te,shouldForwardComponentProp:!0,externalForwardedProps:{...K,...re},ownerState:B,className:s(V.root,l),ref:t,additionalProps:{disabled:m,error:h,fullWidth:g,required:N,color:u,variant:z}}),[oe,se]=f(`input`,{elementType:G,externalForwardedProps:K,additionalProps:X,ownerState:B}),[Q,ce]=f(`inputLabel`,{elementType:p,externalForwardedProps:K,ownerState:B}),[le,ue]=f(`htmlInput`,{elementType:`input`,externalForwardedProps:K,ownerState:B}),[de,fe]=f(`formHelperText`,{elementType:ee,externalForwardedProps:K,ownerState:B}),$=(0,C.jsx)(oe,{"aria-describedby":U,autoComplete:i,autoFocus:a,defaultValue:d,fullWidth:g,multiline:T,name:E,rows:P,maxRows:S,minRows:w,type:ne,value:R,id:H,inputRef:b,onBlur:D,onChange:A,onFocus:j,placeholder:M,inputProps:ue,slots:{input:I.htmlInput?le:void 0},...se});return(0,C.jsxs)(ie,{...ae,children:[x!=null&&x!==``&&(0,C.jsx)(Q,{htmlFor:F&&!Y?void 0:H,id:W,...F&&!Y&&{component:`div`},...ce,children:x}),F?(0,C.jsx)(q,{"aria-describedby":U,id:H,labelId:W,value:R,input:$,...J,children:o}):$,v&&(0,C.jsx)(de,{id:U,...fe,children:v})]})});export{A as t};