import{wt as e}from"./mui-B6lh3XSP.js";import{r as t}from"./ReportFilter-DWQ_hjet.js";import{Bt as n,Ft as r,Gt as i,Nt as a,yt as o}from"./index-KVuxnkWj.js";var s=e(),c=({columns:e,setColumns:c,columnsArray:l,rawValues:u,disabled:d})=>{let{classes:f}=t(),p=o();return(0,s.jsx)(`div`,{className:f.filterItem,children:(0,s.jsxs)(i,{fullWidth:!0,children:[(0,s.jsx)(n,{children:p(`sharedColumns`)}),(0,s.jsx)(a,{label:p(`sharedColumns`),value:e,onChange:e=>c(e.target.value),multiple:!0,disabled:d,children:l.map(([e,t])=>(0,s.jsx)(r,{value:e,children:u?t:p(t)},e))})]})})};export{c as t};