import{i as e}from"./chunk-aKtaBQYM.js";import{K as t,U as n,Vt as r,dt as i,ft as a,tt as o,ut as s,wt as c}from"./mui-B6lh3XSP.js";import{kt as l}from"./index-KVuxnkWj.js";var u=e(r(),1);function d(e){return i(`MuiTableHead`,e)}s(`MuiTableHead`,[`root`]);var f=c(),p=e=>{let{classes:t}=e;return o({root:[`root`]},d,t)},m=t(`thead`,{name:`MuiTableHead`,slot:`Root`})({display:`table-header-group`}),h={variant:`head`},g=`thead`,_=u.forwardRef(function(e,t){let r=n({props:e,name:`MuiTableHead`}),{className:i,component:o=g,...s}=r,c={...r,component:o},u=p(c);return(0,f.jsx)(l.Provider,{value:h,children:(0,f.jsx)(m,{as:o,className:a(u.root,i),ref:t,role:o===g?null:`rowgroup`,ownerState:c,...s})})});export{_ as t};